aboutsummaryrefslogtreecommitdiffstats
path: root/python/tidy/servo_tidy_tests
diff options
context:
space:
mode:
authorAnthony Ramine <n.oxyde@gmail.com>2017-09-25 23:56:32 +0200
committerAnthony Ramine <n.oxyde@gmail.com>2017-09-26 09:48:55 +0200
commit7be32fb2371a14ba61b008a37e79761f66c073c7 (patch)
treef6ff7b73173ce6e39351199d7a5e67386c73659e /python/tidy/servo_tidy_tests
parent0e3c54c1911ba2c3bf305ee04f04fcd9bf2fc2fe (diff)
downloadservo-7be32fb2371a14ba61b008a37e79761f66c073c7.tar.gz
servo-7be32fb2371a14ba61b008a37e79761f66c073c7.zip
Rename JS<T> to Dom<T>
Diffstat (limited to 'python/tidy/servo_tidy_tests')
-rw-r--r--python/tidy/servo_tidy_tests/ban-domrefcell.rs6
-rw-r--r--python/tidy/servo_tidy_tests/test_tidy.py2
2 files changed, 4 insertions, 4 deletions
diff --git a/python/tidy/servo_tidy_tests/test_tidy.py b/python/tidy/servo_tidy_tests/test_tidy.py
index 6a45fd42062..ce9906f5549 100644
--- a/python/tidy/servo_tidy_tests/test_tidy.py
+++ b/python/tidy/servo_tidy_tests/test_tidy.py
@@ -151,7 +151,7 @@ class CheckTidiness(unittest.TestCase):
self.assertNoMoreErrors(ban_errors)
ban_errors = tidy.collect_errors_for_files(iterFile('ban-domrefcell.rs'), [], [tidy.check_rust], print_text=False)
- self.assertEqual('Banned type DOMRefCell<JS<T>> detected. Use MutJS<T> instead', ban_errors.next()[2])
+ self.assertEqual('Banned type DOMRefCell<Dom<T>> detected. Use MutJS<T> instead', ban_errors.next()[2])
self.assertNoMoreErrors(ban_errors)
def test_spec_link(self):
diff --git a/python/tidy/servo_tidy_tests/ban-domrefcell.rs b/python/tidy/servo_tidy_tests/ban-domrefcell.rs
index 9cd8a74ca8c..f41358e7fa7 100644
--- a/python/tidy/servo_tidy_tests/ban-domrefcell.rs
+++ b/python/tidy/servo_tidy_tests/ban-domrefcell.rs
@@ -7,13 +7,13 @@
extern crate script;
+use script::test::Dom;
use script::test::DOMRefCell;
-use script::test::JS;
use script::test::Node;
struct Foo {
- bar: DOMRefCell<JS<Node>>
- //~^ ERROR Banned type DOMRefCell<JS<T>> detected. Use MutJS<T> instead
+ bar: DOMRefCell<Dom<Node>>
+ //~^ ERROR Banned type DOMRefCell<Dom<T>> detected. Use MutJS<T> instead
}
fn main() {}